==> jv-beans-0.1.0-all.zip: jv-beans-0.1.0/src/org/stormcat/jvbeans/dto/child/VoteCountShowDto.java <==
/*
 * Copyright 2009 the Stormcat Project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.stormcat.jvbeans.dto.child;
 
 /**
 * @author jv-beans-gen
 *
 */
public class VoteCountShowDto {

    /** 　　馬番 */
    @org.stormcat.jvbeans.annotation.JvProperty(position = 1, byteLength = 2)
    private java.lang.Integer horseNo;

    /** 　　票数 */
    @org.stormcat.jvbeans.annotation.JvProperty(position = 3, byteLength = 11)
    private java.lang.String voteCount;

    /** 　　人気順 */
    @org.stormcat.jvbeans.annotation.JvProperty(position = 14, byteLength = 2)
    private java.lang.Integer betRank;


    /**
     * @return 　　馬番
     */
    public java.lang.Integer getHorseNo() {
        return horseNo;
    }
    
    /**
     * @param horseNo 　　馬番
     */
    public void setHorseNo(java.lang.Integer horseNo) {
        this.horseNo = horseNo;
    }    
    
    /**
     * @return 　　票数
     */
    public java.lang.String getVoteCount() {
        return voteCount;
    }
    
    /**
     * @param voteCount 　　票数
     */
    public void setVoteCount(java.lang.String voteCount) {
        this.voteCount = voteCount;
    }    
    
    /**
     * @return 　　人気順
     */
    public java.lang.Integer getBetRank() {
        return betRank;
    }
    
    /**
     * @param betRank 　　人気順
     */
    public void setBetRank(java.lang.Integer betRank) {
        this.betRank = betRank;
    }    
    
}

==> jv-beans-0.1.2-all.zip: jv-beans-0.1.2/src/org/stormcat/jvbeans/dto/child/VoteCountShowDto.java <==
/*
 * Copyright 2009 the Stormcat Project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.stormcat.jvbeans.dto.child;
 
 /**
 * @author jv-beans-gen
 *
 */
public class VoteCountShowDto {

    /** 　　馬番 */
    @org.stormcat.jvbeans.annotation.JvProperty(position = 1, byteLength = 2)
    private java.lang.Integer horseNo;

    /** 　　票数 */
    @org.stormcat.jvbeans.annotation.JvProperty(position = 3, byteLength = 11)
    private java.lang.String voteCount;

    /** 　　人気順 */
    @org.stormcat.jvbeans.annotation.JvProperty(position = 14, byteLength = 2)
    private java.lang.String betRank;


    /**
     * @return 　　馬番
     */
    public java.lang.Integer getHorseNo() {
        return horseNo;
    }
    
    /**
     * @param horseNo 　　馬番
     */
    public void setHorseNo(java.lang.Integer horseNo) {
        this.horseNo = horseNo;
    }    
    
    /**
     * @return 　　票数
     */
    public java.lang.String getVoteCount() {
        return voteCount;
    }
    
    /**
     * @param voteCount 　　票数
     */
    public void setVoteCount(java.lang.String voteCount) {
        this.voteCount = voteCount;
    }    
    
    /**
     * @return 　　人気順
     */
    public java.lang.String getBetRank() {
        return betRank;
    }
    
    /**
     * @param betRank 　　人気順
     */
    public void setBetRank(java.lang.String betRank) {
        this.betRank = betRank;
    }    
    
}
